#[non_exhaustive]#[repr(u8)]pub enum CicpColorPrimaries {
SRgb = 1,
Unspecified = 2,
RgbM = 4,
RgbB = 5,
Bt601 = 6,
Rgb240m = 7,
GenericFilm = 8,
Rgb2020 = 9,
Xyz = 10,
SmpteRp431 = 11,
SmpteRp432 = 12,
Industry22 = 22,
}Expand description
Defines the exact color of red, green, blue primary colors.
Each set defines the CIE 1931 XYZ (2°) color space coordinates of the primary colors and an illuminant/whitepoint under which those colors are viewed.
Refer to Rec H.273 Table 2.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SRgb = 1
ITU-R BT.709-6
Unspecified = 2
Explicitly, the color space is not determined.
RgbM = 4
ITU-R BT.470-6 System M
RgbB = 5
ITU-R BT.470-6 System B, G
Bt601 = 6
SMPTE 170M functionally equivalent to 7
Rgb240m = 7
SMPTE 240M functionally equivalent to 6
GenericFilm = 8
Generic film (colour filters using Illuminant C)
Rgb2020 = 9
Rec. ITU-R BT.2020-2 Rec. ITU-R BT.2100-2
Xyz = 10
SMPTE ST 428-1
(CIE 1931 XYZ as in ISO/CIE 11664-1)
SmpteRp431 = 11
SMPTE RP 431-2 (aka. DCI P3)
SmpteRp432 = 12
SMPTE EG 432-1, DCI P3 variant with the D65 whitepoint (matching sRGB and BT.2020)
Industry22 = 22
Corresponds to value 22 but
No corresponding industry specification identified
But moxcms identifies it as EBU Tech 3213-E: https://tech.ebu.ch/docs/tech/tech3213.pdf
However, there are some differences in the second digit of red’s CIE 1931 and the precision is only 2 digits whereas CICP names three; so unsure if this is fully accurate as the actual source material.